@@ -37,12 +37,26 @@ ds_tidy_stats <- function(data, ...) {
     tidyr::drop_na() %>%
     tidyr::gather(vars, values) %>%
     dplyr::group_by(vars) %>%
-    dplyr::summarise_all(dplyr::funs(
-      min = min, max = max, mean = mean, t_mean = trimmed_mean,
-      median = stats::median, mode = ds_mode, range = ds_range, variance = stats::var,
-      stdev = stats::sd, skew = ds_skewness, kurtosis = ds_kurtosis,
-      coeff_var = ds_cvar, q1 = quant1, q3 = quant3, iqrange = stats::IQR),
-      na.rm = TRUE)
+    dplyr::summarise_all(
+      list(
+        min       = min,
+        max       = max,
+        mean      = mean,
+        t_mean    = trimmed_mean,
+        median    = stats::median,
+        mode      = ds_mode,
+        range     = ds_range,
+        variance  = stats::var,
+        stdev     = stats::sd,
+        skew      = ds_skewness,
+        kurtosis  = ds_kurtosis,
+        coeff_var = ds_cvar,
+        q1        = quant1,
+        q3        = quant3,
+        iqrange   = stats::IQR
+      ),
+      na.rm = TRUE
+    )
 }
 
 #' @export
@@ -52,4 +66,4 @@ ds_tidy_stats <- function(data, ...) {
 ds_multi_stats <- function(data, ...) {
   .Deprecated("ds_tidy_stats()")
   ds_tidy_stats(data, ...)
-}
\ No newline at end of file
+}
